@@ -5,7 +5,7 @@
 ;; Author: J.D. Smith <jdtsmith@gmail.com>
 ;; URL: https://github.com/jdtsmith/kind-icon
 ;; Package-Requires: ((emacs "27.1") svg-lib)
-;; Version: 0.1.8
+;; Version: 0.1.9
 ;; Keywords: completion
 
 ;; kind-icon is free software: you can redistribute it
@@ -112,12 +112,12 @@ An vector of two alist for non-terminal and terminal.")
     (snippet "S" :icon "note-text-outline" :face font-lock-string-face)
     (string "s" :icon "sticker-text-outline" :face font-lock-string-face)
     (struct "%" :icon "code-braces" :face font-lock-variable-name-face)
-    (text "tx" :icon "script-text-outline" :face shadow)
+    (text "tx" :icon "script-text-outline" :face font-lock-doc-face)
     (typeparameter "tp" :icon "format-list-bulleted-type" :face font-lock-type-face)
-    (unit "u" :icon "ruler-square" :face shadow)
+    (unit "u" :icon "ruler-square" :face font-lock-constant-face)
     (value "v" :icon "plus-circle-outline" :face font-lock-builtin-face)
     (variable "va" :icon "variable" :face font-lock-variable-name-face)
-    (t "." :icon "crosshairs-question" :face shadow))
+    (t "." :icon "crosshairs-question" :face font-lock-warning-face))
   "Mapping of kinds.
 The format should be an alist of type:
 
@@ -261,11 +261,13 @@ background-color."
 	(if-let ((map (assq kind kind-icon-mapping))
 		 (plist (cddr map)))
 	    (let* ((kind-face (plist-get plist :face))
-		   (col (or
-			 (and kind-face
-			      (face-attribute kind-face :foreground nil t))
-			 (and kind-icon-default-face
-			      (face-attribute kind-icon-default-face :foreground nil t))
+		   (col (or 
+			 (cl-loop for face in `(,kind-face ,kind-icon-default-face)
+				  for fcol = (if-let ((face)
+						      (c (face-attribute face :foreground nil t))
+						      ((not (eq c 'unspecified))))
+						 c)
+				  if fcol return fcol finally return nil)
 			 (frame-parameter nil 'foreground-color)))
 		   (kind-face-bg (and kind-face
 				      (face-attribute kind-face :background nil t)))
